@@ -8,11 +8,6 @@
 #' @param queries List of queries
 #'
 #'   A list of `query()` objects is expected.
-#'
-#' @param meddra_version *Deprecated*, please use `version`
-#'
-#' @param whodd_version *Deprecated*, please use `version`
-#'
 #' @param version Dictionary version
 #'
 #'   The dictionary version used for coding the terms should be specified.
@@ -22,10 +17,6 @@
 #'   *Permitted Values*: A character string (the expected format is
 #'   company-specific)
 #'
-#' @param get_smq_fun *Deprecated*, please use `get_terms_fun`
-#'
-#' @param get_sdg_fun *Deprecated*, please use `get_terms_fun`
-#'
 #' @param get_terms_fun Function which returns the terms
 #'
 #'   For each query specified for the `queries` parameter referring to a basket
@@ -100,7 +91,6 @@
 #'   * `VERSION`: Set to the value of the `version` argument. If it is not
 #'   specified, the variable is not created.
 #'
-#' @author Stefan Bundfuss, Tamara Senior
 #'
 #' @return A dataset to be used as input dataset to the `dataset_queries`
 #'   argument in `derive_vars_query()`
@@ -204,36 +194,8 @@
 #'   version = "20.1"
 #' )
 create_query_data <- function(queries,
-                              meddra_version = deprecated(),
-                              whodd_version = deprecated(),
                               version = NULL,
-                              get_smq_fun = deprecated(),
-                              get_sdg_fun = deprecated(),
                               get_terms_fun = NULL) {
-  if (!missing(meddra_version)) {
-    deprecate_stop(
-      "0.9.0",
-      "create_query_data(meddra_version = )", "create_query_data(version = )"
-    )
-  }
-  if (!missing(whodd_version)) {
-    deprecate_stop(
-      "0.9.0",
-      "create_query_data(whodd_version = )", "create_query_data(version = )"
-    )
-  }
-  if (!missing(get_smq_fun)) {
-    deprecate_stop(
-      "0.9.0",
-      "create_query_data(get_smq_fun = )", "create_query_data(get_terms_fun = )"
-    )
-  }
-  if (!missing(get_sdg_fun)) {
-    deprecate_stop(
-      "0.9.0",
-      "create_query_data(get_sdg_fun = )", "create_query_data(get_terms_fun = )"
-    )
-  }
   # check parameters
   assert_character_scalar(version, optional = TRUE)
   assert_function(get_terms_fun,
@@ -368,7 +330,6 @@ create_query_data <- function(queries,
 #'
 #' @return Output dataset of the access function
 #'
-#' @author Stefan Bundfuss
 get_terms_from_db <- function(version,
                               fun,
                               queries,
@@ -385,12 +346,6 @@ get_terms_from_db <- function(version,
     queries = queries,
     i = i
   )
-  fun_call <- quo(fun(
-    basket_select = definition,
-    version = version,
-    keep_id = expect_query_id,
-    temp_env = temp_env
-  ))
   terms <- call_user_fun(
     fun(
       basket_select = definition,
@@ -433,12 +388,11 @@ get_terms_from_db <- function(version,
 #'
 #' @param i Index of query being checked
 #'
-#' @keywords source_specifications
-#' @family source_specifications
+#' @keywords other_advanced
+#' @family other_advanced
 #'
 #' @return An error is issued if `version` or `fun` is null.
 #'
-#' @author Stefan Bundfuss
 assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name, queries, i) {
   if (is.null(fun)) {
     msg <-
@@ -534,7 +488,6 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
 #'   *Permitted Values*: an `basket_select()` object, a
 #'   data frame, or a list of data frames and `basket_select()` objects.
 #'
-#' @author Stefan Bundfuss
 #'
 #' @seealso [create_query_data()], [basket_select()], [Queries Dataset
 #' Documentation](../articles/queries_dataset.html)
@@ -613,14 +566,14 @@ query <- function(prefix,
                   definition = NULL) {
   out <- list(
     prefix = prefix,
-    name = enquo(name),
-    id = enquo(id),
+    name = enexpr(name),
+    id = enexpr(id),
     add_scope_num = add_scope_num,
     definition = definition
   )
   # evaluate to ensure that name contains the quoted symbol auto or a character
   # string
-  if (!is_auto(out$name) && !quo_is_missing(out$name)) {
+  if (!is_auto(out$name) && !is_missing(out$name)) {
     out$name <- eval_tidy(out$name)
   }
   # evaluate to ensure that id contains the quoted symbol auto or a number
@@ -635,10 +588,9 @@ query <- function(prefix,
 #'
 #' @param obj An object to be validated.
 #'
-#' @author Stefan Bundfuss Tamara Senior
 #'
-#' @keywords source_specifications
-#' @family source_specifications
+#' @keywords other_advanced
+#' @family other_advanced
 #'
 #' @seealso [query()]
 #'
@@ -777,10 +729,9 @@ validate_query <- function(obj) {
 #'
 #' @seealso [create_query_data()], [query()]
 #'
-#' @keywords source_specifications
-#' @family source_specifications
+#' @keywords other_advanced
+#' @family other_advanced
 #'
-#' @author Stefan Bundfuss
 assert_terms <- function(terms,
                          expect_query_name = FALSE,
                          expect_query_id = FALSE,
@@ -868,7 +819,6 @@ assert_terms <- function(terms,
 #'
 #' @return An object of class `basket_select`.
 #'
-#' @author Tamara Senior
 #'
 #' @seealso [create_query_data()], [query()]
 #'
@@ -896,10 +846,9 @@ basket_select <- function(name = NULL,
 #'
 #' @seealso [basket_select()]
 #'
-#' @keywords source_specifications
-#' @family source_specifications
+#' @keywords other_advanced
+#' @family other_advanced
 #'
-#' @author Tamara Senior
 #'
 #' @export
 #'
@@ -940,12 +889,11 @@ validate_basket_select <- function(obj) {
 #'
 #' @return A character representation of the `basket_select()` object
 #'
-#' @author Tamara Senior
 #'
 #' @seealso [basket_select()]
 #'
-#' @keywords source_specifications
-#' @family source_specifications
+#' @keywords other_advanced
+#' @family other_advanced
 #'
 #' @export
 #'
@@ -965,67 +913,3 @@ format.basket_select <- function(x, ...) {
     ")"
   )
 }
-
-#' Create an `smq_select` object
-#'
-#' `r lifecycle::badge("deprecated")`
-#'
-#' This function is *deprecated*, please use `basket_select()` instead.
-#'
-#' @param name Name of the query used to select the definition of the query from
-#'   the company database.
-#'
-#' @param id Identifier of the query used to select the definition of the query
-#'   from the company database.
-#'
-#' @param scope Scope of the query used to select the definition of the query
-#'   from the company database.
-#'
-#'   *Permitted Values*: `"BROAD"`, `"NARROW"`
-#'
-#' @details Exactly one of `name` or `id` must be specified.
-#'
-#' @return An object of class `smq_select`.
-#'
-#' @author Stefan Bundfuss
-#'
-#' @seealso [create_query_data()], [query()]
-#'
-#' @family source_specifications
-#' @keywords source_specifications
-#'
-#' @export
-smq_select <- function(name = NULL,
-                       id = NULL,
-                       scope = NULL) {
-  deprecate_stop("0.9.0", "smq_select()", "basket_select()")
-}
-
-#' Create an `sdg_select` object
-#'
-#' `r lifecycle::badge("deprecated")`
-#'
-#' This function is *deprecated*, please use `basket_select()` instead.
-#'
-#' @param name Name of the query used to select the definition of the query
-#'   from the company database.
-#'
-#' @param id Identifier of the query used to select the definition of the query
-#'   from the company database.
-#'
-#' @details Exactly one `name` or `id` must be specified.
-#'
-#' @return An object of class `sdg_select`.
-#'
-#' @author Stefan Bundfuss
-#'
-#' @seealso [create_query_data()], [query()]
-#'
-#' @family source_specifications
-#' @keywords source_specifications
-#'
-#' @export
-sdg_select <- function(name = NULL,
-                       id = NULL) {
-  deprecate_stop("0.9.0", "sdg_select()", "basket_select()")
-}
