@@ -12,7 +12,7 @@ test_that("derive_param_tte Test 1: new observations with analysis date are deri
     dataset_name = "adsl",
     filter = DTHFL == "Y",
     date = DTHDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "DEATH",
       SRCDOM = "ADSL",
       SRCVAR = "DTHDT"
@@ -23,7 +23,7 @@ test_that("derive_param_tte Test 1: new observations with analysis date are deri
     dataset_name = "adsl",
     date = LSTALVDT,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "LAST KNOWN ALIVE DATE",
       SRCDOM = "ADSL",
       SRCVAR = "LSTALVDT"
@@ -48,7 +48,7 @@ test_that("derive_param_tte Test 1: new observations with analysis date are deri
     event_conditions = list(death),
     censor_conditions = list(lstalv),
     source_datasets = list(adsl = adsl),
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "OS",
       PARAM = "Overall Survival"
     )
@@ -89,7 +89,7 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
     dataset_name = "adrs",
     filter = AVALC == "PD",
     date = ADTM,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "PD",
       SRCDOM = "ADRS",
       SRCVAR = "ADTM",
@@ -101,7 +101,7 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
     dataset_name = "adsl",
     filter = DTHFL == "Y",
     date = DTHDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "DEATH",
       SRCDOM = "ADSL",
       SRCVAR = "DTHDT"
@@ -112,7 +112,7 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
     dataset_name = "adrs",
     date = ADTM,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "LAST TUMOR ASSESSMENT",
       SRCDOM = "ADRS",
       SRCVAR = "ADTM"
@@ -123,7 +123,7 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
     dataset_name = "adsl",
     date = TRTSDTM,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "TREATMENT START",
       SRCDOM = "ADSL",
       SRCVAR = "TRTSDTM"
@@ -157,7 +157,7 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
     censor_conditions = list(lastvisit, start),
     source_datasets = list(adsl = adsl, adrs = adrs),
     create_datetime = TRUE,
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "PFS",
       PARAM = "Progression Free Survival"
     )
@@ -170,8 +170,112 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
   )
 })
 
-## Test 3: error is issued if DTC variables specified for date ----
-test_that("derive_param_tte Test 3: error is issued if DTC variables specified for date", {
+## Test 3: no new observations for subjects not in ADSL ----
+test_that("derive_param_tte Test 3: no new observations for subjects not in ADSL", {
+  adsl <- tibble::tribble(
+    ~USUBJID, ~DTHFL, ~DTHDT,            ~RSPDT,
+    "01",     "Y",    ymd("2021-06-12"), ymd("2021-03-04"),
+    "02",     "N",    NA,                NA,
+    "03",     "Y",    ymd("2021-08-21"), NA,
+    "04",     "N",    NA,                ymd("2021-04-14"),
+    "05",     "N",    NA,                NA
+  ) %>%
+    mutate(STUDYID = "AB42")
+
+  adrs <- tibble::tribble(
+    ~USUBJID, ~AVALC, ~ADT,              ~ASEQ,
+    "01",     "SD",   ymd("2021-01-03"), 1,
+    "01",     "PR",   ymd("2021-03-04"), 2,
+    "01",     "PD",   ymd("2021-05-05"), 3,
+    "02",     "PD",   ymd("2021-02-03"), 1,
+    "04",     "SD",   ymd("2021-02-13"), 1,
+    "04",     "PR",   ymd("2021-04-14"), 2,
+    "04",     "CR",   ymd("2021-05-15"), 3
+  ) %>%
+    mutate(STUDYID = "AB42", PARAMCD = "OVR")
+
+  pd <- event_source(
+    dataset_name = "adrs",
+    filter = AVALC == "PD",
+    date = ADT,
+    set_values_to = exprs(
+      EVENTDESC = "PD",
+      SRCDOM = "ADRS",
+      SRCVAR = "ADTM",
+      SRCSEQ = ASEQ
+    )
+  )
+
+  death <- event_source(
+    dataset_name = "adsl",
+    filter = DTHFL == "Y",
+    date = DTHDT,
+    set_values_to = exprs(
+      EVENTDESC = "DEATH",
+      SRCDOM = "ADSL",
+      SRCVAR = "DTHDT"
+    )
+  )
+
+  lastvisit <- censor_source(
+    dataset_name = "adrs",
+    date = ADT,
+    censor = 1,
+    set_values_to = exprs(
+      EVENTDESC = "LAST TUMOR ASSESSMENT",
+      SRCDOM = "ADRS",
+      SRCVAR = "ADTM",
+      SRCSEQ = ASEQ
+    )
+  )
+
+  first_response <- censor_source(
+    dataset_name = "adsl",
+    date = RSPDT,
+    censor = 1,
+    set_values_to = exprs(
+      EVENTDESC = "FIRST RESPONSE",
+      SRCDOM = "ADSL",
+      SRCVAR = "RSPDT"
+    )
+  )
+
+  expected_output <- tibble::tribble(
+    ~USUBJID, ~ADT,              ~CNSR, ~EVENTDESC,              ~SRCDOM, ~SRCVAR,   ~SRCSEQ,
+    "01",     ymd("2021-05-05"),    0L, "PD",                    "ADRS",  "ADTM",          3,
+    "04",     ymd("2021-05-15"),    1L, "LAST TUMOR ASSESSMENT", "ADRS",  "ADTM",          3,
+  ) %>%
+    mutate(
+      STUDYID = "AB42",
+      PARAMCD = "DURRSP",
+      PARAM = "Duration of Response"
+    ) %>%
+    left_join(
+      select(adsl, USUBJID, STARTDT = RSPDT),
+      by = "USUBJID"
+    )
+
+  actual_output <- derive_param_tte(
+    dataset_adsl = filter(adsl, !is.na(RSPDT)),
+    start_date = RSPDT,
+    event_conditions = list(pd, death),
+    censor_conditions = list(lastvisit, first_response),
+    source_datasets = list(adsl = adsl, adrs = adrs),
+    set_values_to = exprs(
+      PARAMCD = "DURRSP",
+      PARAM = "Duration of Response"
+    )
+  )
+
+  expect_dfs_equal(
+    actual_output,
+    expected_output,
+    keys = c("USUBJID", "PARAMCD")
+  )
+})
+
+## Test 4: error is issued if DTC variables specified for date ----
+test_that("derive_param_tte Test 4: error is issued if DTC variables specified for date", {
   adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
@@ -190,7 +294,7 @@ test_that("derive_param_tte Test 3: error is issued if DTC variables specified f
   ttae <- event_source(
     dataset_name = "ae",
     date = AESTDTC,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "AE",
       SRCDOM = "AE",
       SRCVAR = "AESTDTC",
@@ -202,7 +306,7 @@ test_that("derive_param_tte Test 3: error is issued if DTC variables specified f
     dataset_name = "adsl",
     date = EOSDT,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "END OF STUDY",
       SRCDOM = "ADSL",
       SRCVAR = "EOSDT"
@@ -216,7 +320,7 @@ test_that("derive_param_tte Test 3: error is issued if DTC variables specified f
       event_conditions = list(ttae),
       censor_conditions = list(eos),
       source_datasets = list(adsl = adsl, ae = ae),
-      set_values_to = vars(
+      set_values_to = exprs(
         PARAMCD = "TTAE",
         PARAM = "Time to First Adverse Event"
       )
@@ -225,8 +329,8 @@ test_that("derive_param_tte Test 3: error is issued if DTC variables specified f
   )
 })
 
-## Test 4: by_vars parameter works correctly ----
-test_that("derive_param_tte Test 4: by_vars parameter works correctly", {
+## Test 5: by_vars parameter works correctly ----
+test_that("derive_param_tte Test 5: by_vars parameter works correctly", {
   adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
@@ -248,7 +352,7 @@ test_that("derive_param_tte Test 4: by_vars parameter works correctly", {
   ttae <- event_source(
     dataset_name = "ae",
     date = AESTDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "AE",
       SRCDOM = "AE",
       SRCVAR = "AESTDTC",
@@ -260,7 +364,7 @@ test_that("derive_param_tte Test 4: by_vars parameter works correctly", {
     dataset_name = "adsl",
     date = EOSDT,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "END OF STUDY",
       SRCDOM = "ADSL",
       SRCVAR = "EOSDT"
@@ -286,12 +390,12 @@ test_that("derive_param_tte Test 4: by_vars parameter works correctly", {
   expect_dfs_equal(
     derive_param_tte(
       dataset_adsl = adsl,
-      by_vars = vars(AEDECOD),
+      by_vars = exprs(AEDECOD),
       start_date = TRTSDT,
       event_conditions = list(ttae),
       censor_conditions = list(eos),
       source_datasets = list(adsl = adsl, ae = ae),
-      set_values_to = vars(
+      set_values_to = exprs(
         PARAMCD = paste0("TTAE", as.numeric(as.factor(AEDECOD))),
         PARAM = paste("Time to First", AEDECOD, "Adverse Event"),
         PARCAT1 = "TTAE",
@@ -303,8 +407,8 @@ test_that("derive_param_tte Test 4: by_vars parameter works correctly", {
   )
 })
 
-## Test 5: an error is issued if some of the by variables are missing ----
-test_that("derive_param_tte Test 5: an error is issued if some of the by variables are missing", {
+## Test 6: an error is issued if some of the by variables are missing ----
+test_that("derive_param_tte Test 6: an error is issued if some of the by variables are missing", {
   adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
@@ -326,7 +430,7 @@ test_that("derive_param_tte Test 5: an error is issued if some of the by variabl
   ttae <- event_source(
     dataset_name = "ae",
     date = AESTDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "AE",
       SRCDOM = "AE",
       SRCVAR = "AESTDTC",
@@ -338,7 +442,7 @@ test_that("derive_param_tte Test 5: an error is issued if some of the by variabl
     dataset_name = "adsl",
     date = EOSDT,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "END OF STUDY",
       SRCDOM = "ADSL",
       SRCVAR = "EOSDT"
@@ -348,12 +452,12 @@ test_that("derive_param_tte Test 5: an error is issued if some of the by variabl
   expect_error(
     derive_param_tte(
       dataset_adsl = adsl,
-      by_vars = vars(AEBODSYS, AEDECOD),
+      by_vars = exprs(AEBODSYS, AEDECOD),
       start_date = TRTSDT,
       event_conditions = list(ttae),
       censor_conditions = list(eos),
       source_datasets = list(adsl = adsl, ae = ae),
-      set_values_to = vars(
+      set_values_to = exprs(
         PARAMCD = paste0("TTAE", as.numeric(as.factor(AEDECOD))),
         PARAM = paste("Time to First", AEDECOD, "Adverse Event"),
         PARCAT1 = "TTAE",
@@ -364,8 +468,8 @@ test_that("derive_param_tte Test 5: an error is issued if some of the by variabl
   )
 })
 
-## Test 6: errors if all by vars are missing in all source datasets ----
-test_that("derive_param_tte Test 6: errors if all by vars are missing in all source datasets", {
+## Test 7: errors if all by vars are missing in all source datasets ----
+test_that("derive_param_tte Test 7: errors if all by vars are missing in all source datasets", {
   adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
@@ -387,7 +491,7 @@ test_that("derive_param_tte Test 6: errors if all by vars are missing in all sou
   ttae <- event_source(
     dataset_name = "ae",
     date = AESTDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "AE",
       SRCDOM = "AE",
       SRCVAR = "AESTDTC",
@@ -399,7 +503,7 @@ test_that("derive_param_tte Test 6: errors if all by vars are missing in all sou
     dataset_name = "adsl",
     date = EOSDT,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "END OF STUDY",
       SRCDOM = "ADSL",
       SRCVAR = "EOSDT"
@@ -409,12 +513,12 @@ test_that("derive_param_tte Test 6: errors if all by vars are missing in all sou
   expect_error(
     derive_param_tte(
       dataset_adsl = adsl,
-      by_vars = vars(AEBODSYS),
+      by_vars = exprs(AEBODSYS),
       start_date = TRTSDT,
       event_conditions = list(ttae),
       censor_conditions = list(eos),
       source_datasets = list(adsl = adsl, ae = ae),
-      set_values_to = vars(
+      set_values_to = exprs(
         PARAMCD = paste0("TTAE", as.numeric(as.factor(AEDECOD))),
         PARAM = paste("Time to First", AEDECOD, "Adverse Event"),
         PARCAT1 = "TTAE",
@@ -426,8 +530,8 @@ test_that("derive_param_tte Test 6: errors if all by vars are missing in all sou
   )
 })
 
-## Test 7: errors if PARAMCD and by_vars are not one to one ----
-test_that("derive_param_tte Test 7: errors if PARAMCD and by_vars are not one to one", {
+## Test 8: errors if PARAMCD and by_vars are not one to one ----
+test_that("derive_param_tte Test 8: errors if PARAMCD and by_vars are not one to one", {
   adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
@@ -449,7 +553,7 @@ test_that("derive_param_tte Test 7: errors if PARAMCD and by_vars are not one to
   ttae <- event_source(
     dataset_name = "ae",
     date = AESTDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "AE",
       SRCDOM = "AE",
       SRCVAR = "AESTDTC",
@@ -461,7 +565,7 @@ test_that("derive_param_tte Test 7: errors if PARAMCD and by_vars are not one to
     dataset_name = "adsl",
     date = EOSDT,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "END OF STUDY",
       SRCDOM = "ADSL",
       SRCVAR = "EOSDT"
@@ -471,12 +575,12 @@ test_that("derive_param_tte Test 7: errors if PARAMCD and by_vars are not one to
   expect_error(
     derive_param_tte(
       dataset_adsl = adsl,
-      by_vars = vars(AEDECOD),
+      by_vars = exprs(AEDECOD),
       start_date = TRTSDT,
       event_conditions = list(ttae),
       censor_conditions = list(eos),
       source_datasets = list(adsl = adsl, ae = ae),
-      set_values_to = vars(
+      set_values_to = exprs(
         PARAMCD = "TTAE",
         PARCAT2 = AEDECOD
       )
@@ -489,8 +593,8 @@ test_that("derive_param_tte Test 7: errors if PARAMCD and by_vars are not one to
   )
 })
 
-## Test 8: errors if set_values_to contains invalid expressions ----
-test_that("derive_param_tte Test 8: errors if set_values_to contains invalid expressions", {
+## Test 9: errors if set_values_to contains invalid expressions ----
+test_that("derive_param_tte Test 9: errors if set_values_to contains invalid expressions", {
   adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
@@ -512,7 +616,7 @@ test_that("derive_param_tte Test 8: errors if set_values_to contains invalid exp
   ttae <- event_source(
     dataset_name = "ae",
     date = AESTDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "AE",
       SRCDOM = "AE",
       SRCVAR = "AESTDTC",
@@ -524,7 +628,7 @@ test_that("derive_param_tte Test 8: errors if set_values_to contains invalid exp
     dataset_name = "adsl",
     date = EOSDT,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "END OF STUDY",
       SRCDOM = "ADSL",
       SRCVAR = "EOSDT"
@@ -534,12 +638,12 @@ test_that("derive_param_tte Test 8: errors if set_values_to contains invalid exp
   expect_error(
     derive_param_tte(
       dataset_adsl = adsl,
-      by_vars = vars(AEDECOD),
+      by_vars = exprs(AEDECOD),
       start_date = TRTSDT,
       event_conditions = list(ttae),
       censor_conditions = list(eos),
       source_datasets = list(adsl = adsl, ae = ae),
-      set_values_to = vars(
+      set_values_to = exprs(
         PARAMCD = paste0("TTAE", as.numeric(as.factor(AEDECOD))),
         PARAM = past("Time to First", AEDECOD, "Adverse Event"),
         PARCAT1 = "TTAE",
@@ -560,8 +664,8 @@ test_that("derive_param_tte Test 8: errors if set_values_to contains invalid exp
   )
 })
 
-## Test 9: error is issued if parameter code already exists ----
-test_that("derive_param_tte Test 9: error is issued if parameter code already exists", {
+## Test 10: error is issued if parameter code already exists ----
+test_that("derive_param_tte Test 10: error is issued if parameter code already exists", {
   adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
@@ -583,7 +687,7 @@ test_that("derive_param_tte Test 9: error is issued if parameter code already ex
   ttae <- event_source(
     dataset_name = "ae",
     date = AESTDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "AE",
       SRCDOM = "AE",
       SRCVAR = "AESTDTC",
@@ -595,7 +699,7 @@ test_that("derive_param_tte Test 9: error is issued if parameter code already ex
     dataset_name = "adsl",
     date = EOSDT,
     censor = 1,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVENTDESC = "END OF STUDY",
       SRCDOM = "ADSL",
       SRCVAR = "EOSDT"
@@ -622,7 +726,7 @@ test_that("derive_param_tte Test 9: error is issued if parameter code already ex
       event_conditions = list(ttae),
       censor_conditions = list(eos),
       source_datasets = list(adsl = adsl, ae = ae),
-      set_values_to = vars(
+      set_values_to = exprs(
         PARAMCD = "TTAE",
         PARAM = "Time to First Adverse Event"
       )
@@ -631,8 +735,8 @@ test_that("derive_param_tte Test 9: error is issued if parameter code already ex
   )
 })
 
-## Test 10: ensuring ADT is not NA because of missing start_date ----
-test_that("derive_param_tte Test 10: ensuring ADT is not NA because of missing start_date", {
+## Test 11: ensuring ADT is not NA because of missing start_date ----
+test_that("derive_param_tte Test 11: ensuring ADT is not NA because of missing start_date", {
   adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,                ~LSTALVDT,
     "01",     NA,                     ymd("2022-08-10"),
@@ -652,7 +756,7 @@ test_that("derive_param_tte Test 10: ensuring ADT is not NA because of missing s
   eos <- censor_source(
     "adsl",
     date = LSTALVDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVNTDESC = "Last Known Alive Date",
       SRCDOM = "ADSL",
       SRCVAR = "LSTALVDT"
@@ -662,7 +766,7 @@ test_that("derive_param_tte Test 10: ensuring ADT is not NA because of missing s
   ttae <- event_source(
     dataset_name = "adae",
     date = ASTDT,
-    set_values_to = vars(
+    set_values_to = exprs(
       EVNTDESC = "Any Adverse Event",
       SRCDOM = "ADAE",
       SRCVAR = "AEDECOD",
@@ -676,7 +780,7 @@ test_that("derive_param_tte Test 10: ensuring ADT is not NA because of missing s
     start_date = TRTSDT,
     event_conditions = list(ttae),
     censor_conditions = list(eos),
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "ANYAETTE",
       PARAM = "Time to any first adverse event"
     )
@@ -701,16 +805,16 @@ test_that("derive_param_tte Test 10: ensuring ADT is not NA because of missing s
   )
 })
 
-## Test 11: error is issued if package does not exist ----
-test_that("list_tte_source_objects Test 10: error is issued if package does not exist", {
+## Test 12: error is issued if package does not exist ----
+test_that("derive_param_tte Test 12: error is issued if package does not exist", {
   expect_error(
     list_tte_source_objects(package = "tte"),
     regexp = "No package called 'tte' is installed and hence no `tte_source` objects are available"
   )
 })
 
-## Test 12: calling list_tte_source_objects results in expected output objects ----
-test_that("list_tte_source_objects Test 11: expected objects produced", {
+## Test 13: expected objects produced ----
+test_that("derive_param_tte Test 13: expected objects produced", {
   expected_output <- tibble::tribble(
     ~object, ~dataset_name, ~filter, ~date, ~censor,
     "ae_ser_event", "adae", quote(TRTEMFL == "Y" & AESER == "Y"), "ASTDT", 0,
